##  Configurability of Dashboard Panels
The obsolescence risk management dashboard comes with four default panels and is not configurable. However, you have the option to create a custom dashboard based on it and add more panels relevant to your needs. To find out more, refer to [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.").
You can include elements such as reports, to-dos, survey statuses, KPIs, and so on. By creating your own KPIs and adding them to the dashboard, you can encourage stakeholder participation, provide actionable insights for use cases, and display strategies and objectives. To learn more, see [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Configure KPIs and display them on dashboards to track enterprise architecture metrics.").
